#!/usr/bin/env python
# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import logging
import lazr
from ci_utils import launchpad

log = logging.getLogger('ppahandler')


def create_ppa(name, displayname, description=None, private=False):
    lp = launchpad.lp_login()
    user = lp.people[launchpad.get_lp_user_name()]
    log.info("Attempting to create PPA with name: {} "
             "for the user: {}".format(name, user.name))
    try:
        ppa = user.createPPA(name=name,
                             displayname=displayname,
                             description=description,
                             private=private)
    except lazr.restfulclient.errors.BadRequest:
        log.info("PPA {} already exists".format(name))
        ppa = user.getPPAByName(name=name)
    finally:
        ppa_name = "ppa:{}/{}".format(user.name, ppa.name)
        return ppa_name
