# Ubuntu CI Engine
# Copyright 2014 Canonical Ltd.

# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3, as
# published by the Free Software Foundation.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import mock
import unittest
from ci_utils import amqp_utils
import logging
from ucitests import (
    assertions,
)
from ci_utils.testing import (
    fixtures,
)

from ppacreator import run_worker


class TestPPACreatorWorker(unittest.TestCase):
    def setUp(self):
        super(TestPPACreatorWorker, self).setUp()
        self.queue = fixtures.FakeTaskQueue('ppacreate')
        self.logger = logging.getLogger()

    def assertTestRun(self, params):
        worker = run_worker.PPACreatorWorker()
        self.queue.publish(params)
        returns = self.queue.subscribe(worker.handle_request, self.logger)
        assertions.assertLength(self, 1, returns)
        self.assertTrue(self.queue.is_empty())
        return returns

    @mock.patch('ppacreator.run_worker.create_ppa')
    @mock.patch('ci_utils.amqp_utils.progress_completed')
    def test_handle_request(self, mocked_progress_completed,
                            mocked_create_ppa):
        params = {
            'name': 'fake-ppa',
            'displayname': 'fake-ppa-displayname',
            'description': 'fake-description',
            'private': True,
            'progress_trigger': 'ticket_1_trigger',
            'ticket_id': 'fake-ticket-id'
        }
        returns = self.assertTestRun(params)
        (retcode, results) = returns[0]
        self.assertEqual(amqp_utils.progress_completed, retcode)
